@@ -1,9 +1,9 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/api.lisp,v 1.61 2005/12/06 16:50:50 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/api.lisp,v 1.63 2006/02/13 16:45:34 edi Exp $
 
 ;;; The external API for creating and using scanners.
 
-;;; Copyright (c) 2002-2005, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2002-2006, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -280,9 +280,8 @@ internal purposes."))
 (define-compiler-macro scan (&whole form &environment env regex target-string &rest rest)
   "Make sure that constant forms are compiled into scanners at compile time."
   (cond ((constantp regex env)
-          `(scan (load-time-value
-                   (create-scanner ,regex))
-                   ,target-string ,@rest))
+          `(scan (load-time-value (create-scanner ,regex))
+                 ,target-string ,@rest))
         (t form)))
 
 (defun scan-to-strings (regex target-string &key (start 0)
@@ -315,8 +314,7 @@ structure with TARGET-STRING."
     (&whole form &environment env regex target-string &rest rest)
   "Make sure that constant forms are compiled into scanners at compile time."
   (cond ((constantp regex env)
-          `(scan-to-strings (load-time-value
-                              (create-scanner ,regex))
+          `(scan-to-strings (load-time-value (create-scanner ,regex))
                             ,target-string ,@rest))
         (t form)))
 
@@ -529,8 +527,7 @@ the scan is continued one position behind this match."
    "Make sure that constant forms are compiled into scanners at
 compile time."
    (cond ((constantp regex env)
-           `(all-matches (load-time-value
-                           (create-scanner ,regex))
+           `(all-matches (load-time-value (create-scanner ,regex))
 			 ,@rest))
          (t form)))
 
@@ -554,9 +551,8 @@ share structure with TARGET-STRING."
 compile time."
    (cond ((constantp regex env)
            `(all-matches-as-strings
-	    (load-time-value
-              (create-scanner ,regex))
-	    ,@rest))
+             (load-time-value (create-scanner ,regex))
+             ,@rest))
          (t form)))
 
 (defun split (regex target-string
@@ -634,8 +630,7 @@ TARGET-STRING."
 (define-compiler-macro split (&whole form &environment env regex target-string &rest rest)
   "Make sure that constant forms are compiled into scanners at compile time."
   (cond ((constantp regex env)
-          `(split (load-time-value
-                    (create-scanner ,regex))
+          `(split (load-time-value (create-scanner ,regex))
                   ,target-string ,@rest))
         (t form)))
 
@@ -994,8 +989,7 @@ match."
     (&whole form &environment env regex target-string replacement &rest rest)
   "Make sure that constant forms are compiled into scanners at compile time."
   (cond ((constantp regex env)
-          `(regex-replace (load-time-value
-                            (create-scanner ,regex))
+          `(regex-replace (load-time-value (create-scanner ,regex))
                           ,target-string ,replacement ,@rest))
         (t form)))
 
@@ -1052,8 +1046,7 @@ match."
     (&whole form &environment env regex target-string replacement &rest rest)
   "Make sure that constant forms are compiled into scanners at compile time."
   (cond ((constantp regex env)
-          `(regex-replace-all (load-time-value
-                                (create-scanner ,regex))
+          `(regex-replace-all (load-time-value (create-scanner ,regex))
                               ,target-string ,replacement ,@rest))
         (t form)))
 
